@@ -14,18 +14,19 @@ import mns_common.component.trade_date.trade_date_common_service_api as trade_da
 import pandas as pd
 import mns_common.constant.db_name_constant as db_name_constant
 import mns_common.utils.data_frame_util as data_frame_util
-
+import mns_common.component.common_service_fun_api as common_service_fun_api
 mongodb_util = MongodbUtil('27017')
+from loguru import logger
 
 
 @lru_cache(maxsize=None)
 def get_last_trade_day_zt(str_day):
     last_trade_day = trade_date_common_service_api.get_last_trade_day(str_day)
     query = {'str_day': last_trade_day}
-    db_stock_zt_pool = mongodb_util.find_query_data(db_name_constant.STOCK_ZT_POOL, query)
-    if db_stock_zt_pool is None or db_stock_zt_pool.shape[0] == 0:
-        db_stock_zt_pool = stock_zt_pool_api.stock_em_zt_pool_df(date_handle_util.no_slash_date(last_trade_day))
-    return db_stock_zt_pool
+    last_trade_day_zt = mongodb_util.find_query_data(db_name_constant.STOCK_ZT_POOL, query)
+    if last_trade_day_zt is None or last_trade_day_zt.shape[0] == 0:
+        last_trade_day_zt = stock_zt_pool_api.stock_em_zt_pool_df(date_handle_util.no_slash_date(last_trade_day))
+    return last_trade_day_zt
 
 
 # 按照字段分组
@@ -100,7 +101,7 @@ def group_industry_zt_by_field(industry_realtime_quotes_now, field):
                                      left_index=True, right_index=True)
     # 0-5 之间涨幅的
     industry_realtime_quotes_now_low_chg = industry_realtime_quotes_now.loc[
-        (industry_realtime_quotes_now['chg'] <= 5) & (
+        (industry_realtime_quotes_now['chg'] < 5) & (
                 industry_realtime_quotes_now['chg'] >= 0)]
 
     if industry_realtime_quotes_now_low_chg.shape[0] == 0:
@@ -117,7 +118,7 @@ def group_industry_zt_by_field(industry_realtime_quotes_now, field):
     # 跌幅在0到-9之间的
 
     industry_realtime_quotes_now_negative_chg = industry_realtime_quotes_now.loc[
-        (industry_realtime_quotes_now['chg'] <= 0) & (
+        (industry_realtime_quotes_now['chg'] < 0) & (
                 industry_realtime_quotes_now['chg'] >= -9)]
 
     if industry_realtime_quotes_now_negative_chg.shape[0] == 0:
@@ -133,7 +134,7 @@ def group_industry_zt_by_field(industry_realtime_quotes_now, field):
 
     # 跌幅大于9%的
     industry_realtime_quotes_now_dt = industry_realtime_quotes_now.loc[
-        (industry_realtime_quotes_now['chg'] <= -9)]
+        (industry_realtime_quotes_now['chg'] < -9)]
 
     if industry_realtime_quotes_now_dt.shape[0] == 0:
         zt_group_industry[field + '_' + 'dt_chg_number'] = 0
@@ -195,5 +196,50 @@ def get_period_five_boards_zt_pool(begin_day, end_day):
     return zt_symbol_list
 
 
+'''
+涨停原因分组统计
+'''
+
+
+def zt_reason_group(zt_pool_df):
+    if data_frame_util.is_empty(zt_pool_df):
+        return pd.DataFrame()
+
+    zt_pool_df = common_service_fun_api.exclude_st_symbol(zt_pool_df)
+    if data_frame_util.is_empty(zt_pool_df):
+        return pd.DataFrame()
+
+    zt_pool_df['symbol'] = zt_pool_df['symbol'].astype(str)
+    result_group_df = None
+    for zt_stock_one in zt_pool_df.itertuples():
+        try:
+            zt_reason = zt_stock_one.zt_reason
+            if data_frame_util.is_string_empty(zt_reason):
+                continue
+            zt_reason_list = zt_reason.split("+")
+            if len(zt_reason_list) > 0:
+                for zt_reason_one in zt_reason_list:
+                    zt_reason_dict = {'zt_reason_name': zt_reason_one,
+                                      'number': 1
+                                      }
+                    zt_reason_df_new = pd.DataFrame(zt_reason_dict, index=[0])
+                    if result_group_df is None:
+                        result_group_df = zt_reason_df_new
+                    else:
+                        exist_zt_reason = result_group_df.loc[result_group_df['zt_reason_name'] == zt_reason_one]
+                        if data_frame_util.is_not_empty(exist_zt_reason):
+                            result_group_df.loc[result_group_df['zt_reason_name'] == zt_reason_one, "number"] = \
+                                exist_zt_reason['number'] + 1
+                        else:
+                            result_group_df = pd.concat([result_group_df, zt_reason_df_new])
+
+        except BaseException as e:
+            logger.error("涨停原因分组出现异常:{},{}", zt_stock_one.symbol, e)
+    if data_frame_util.is_not_empty(result_group_df):
+        result_group_df = result_group_df.sort_values(by=['number'], ascending=False)
+
+    return result_group_df
+
+
 if __name__ == '__main__':
     get_last_trade_day_zt('20231215')
