@@ -10,9 +10,7 @@ import pymongo
 from mns_common.utils.async_fun import async_fun
 from loguru import logger
 import mns_common.utils.ip_util as ip_util
-import warnings
 
-warnings.filterwarnings("ignore")
 
 
 class MongodbUtil:
@@ -21,18 +19,18 @@ class MongodbUtil:
 
     def get_db(self):
         port = self.port
+        mac_address = ip_util.get_mac_address()
         if port == "remote":
             client = pymongo.MongoClient("mongodb://100.87.2.149:" + '27017' + "/patience")
         elif port == "remote1":
             client = pymongo.MongoClient("mongodb://100.87.2.149:" + '27019' + "/patience")
         # 家里
-        elif '192.168.1' in ip_util.get_host_ip():
+        elif mac_address is not None and mac_address == ip_util.WINDOWS_MAC_ADDRESS_CD:
+            client = pymongo.MongoClient("mongodb://127.0.0.1:" + port + "/patience")
+        elif '192.168.1' in ip_util.get_host_ip() and mac_address is not None and mac_address == ip_util.APPLE_AIR_MAC_ADDRESS:
             client = pymongo.MongoClient("mongodb://127.0.0.1:" + port + "/patience")
-        # 新都
-        elif '192.168.68' in ip_util.get_host_ip():
-            client = pymongo.MongoClient("mongodb://100.87.2.149:" + port + "/patience")
         else:
-            client = pymongo.MongoClient("mongodb://100.87.2.149:" + port + "/patience")
+            client = pymongo.MongoClient("mongodb://127.0.0.1:" + port + "/patience")
         return client.patience
 
     def group(self, query, coll_name):
@@ -137,12 +135,11 @@ class MongodbUtil:
         collection = db[database]
         # 格式转换
         try:
-            df = df.drop_duplicates()
             # df = df.T.drop_duplicates().T
             records = df.to_dict('records')
             collection.insert_many(records)
-        except BaseException:
-            logger.error("插入数据异常" + df)
+        except BaseException as e:
+            logger.error("插入数据异常:{}", e)
 
     def insert_mongo_json(self, json, database):
         db = self.get_db()
@@ -269,50 +266,51 @@ class MongodbUtil:
 #     print(result)
 from io import StringIO
 import re
+
 if __name__ == '__main__':
     mongodb_util = MongodbUtil('27017')
     #
     # kpl_best_choose_index_df = mongodb_util.find_page_skip_data('kpl_best_choose_index', {"index_class": "sub_index"},
     #                                                             1, 100, 'create_time', True)
-    key_word ='高速连接'
+    key_word = '高速连接'
     EXCLUDE_INFO_KEY = '股东人数'
-    query = {
-        "$or": [{'question': {"$regex": re.compile(key_word, re.IGNORECASE)}},
-                {'answer_content': {"$regex": re.compile(key_word, re.IGNORECASE)}}],
-        "$and": [{'question': {"$not": re.compile(EXCLUDE_INFO_KEY, re.IGNORECASE)}},
-                 {'answer_content': {"$not": re.compile(EXCLUDE_INFO_KEY, re.IGNORECASE)}}],
-    }
-
-    pipeline = [
-        {'$match':query},
-        {'$group': {'_id': "$symbol", 'count': {'$sum': 1}}}
-    ]
-    result = mongodb_util.aggregate(pipeline, 'stock_interactive_question')
-
-    result = result.sort_values(by=['_id'], ascending=True)
-    print(result)
-
-    # ths_new_concept = mongodb_util.find_all_data('ths_new_concept')
-    key = mongodb_util.get_col_keys('company_info')
-    print(key)
+    # query = {
+    #     "$or": [{'question': {"$regex": re.compile(key_word, re.IGNORECASE)}},
+    #             {'answer_content': {"$regex": re.compile(key_word, re.IGNORECASE)}}],
+    #     "$and": [{'question': {"$not": re.compile(EXCLUDE_INFO_KEY, re.IGNORECASE)}},
+    #              {'answer_content': {"$not": re.compile(EXCLUDE_INFO_KEY, re.IGNORECASE)}}],
+    # }
+    #
+    # pipeline = [
+    #     {'$match': query},
+    #     {'$group': {'_id': "$symbol", 'count': {'$sum': 1}}}
+    # ]
+    # result = mongodb_util.aggregate(pipeline, 'stock_interactive_question')
+    #
+    # result = result.sort_values(by=['_id'], ascending=True)
+    # print(result)
+    #
+    # # ths_new_concept = mongodb_util.find_all_data('ths_new_concept')
+    # key = mongodb_util.get_col_keys('company_info')
+    # print(key)
 
     # mongodb_util.create_index('realtime_quotes_now_open', [("number", 1)])
     # mongodb_util.create_index('realtime_quotes_now_open', [("symbol", 1), ("number", 1)])
     # mongodb_util.create_index('realtime_quotes_now_open', [("str_day", 1)])
     # update_query = {"str_day": "2023-06-30"}
     # mongodb_util.update_many(update_query, {"$set": {"number": 1}}, "realtime_quotes_now_open")
-    query = {"symbol": "000617"}
-    company_info_base = mongodb_util.find_query_data('company_info_base', query)
-    ths_stock_concept_detail = mongodb_util.find_query_data('ths_stock_concept_detail', query)
-    ths_stock_concept_detail = ths_stock_concept_detail[[
-        'concept_code',
-        'concept_name',
-        'str_now_time',
-        'concept_create_day']]
-    # 去除空格
-    ths_stock_concept_detail['concept_name'] = ths_stock_concept_detail['concept_name'].str.replace(' ', '')
-    company_info_base.loc[:, 'ths_concept_list_info'] = ths_stock_concept_detail.to_string(index=False)
-    for company_one in company_info_base.itertuples():
-        ths_concept_list_info = company_one.ths_concept_list_info
-        ths_concept_list_info_df = pd.read_csv(StringIO(ths_concept_list_info), delim_whitespace=True)
-        print(ths_concept_list_info_df)
+    # query = {"symbol": "000617"}
+    # company_info_base = mongodb_util.find_query_data('company_info_base', query)
+    # ths_stock_concept_detail = mongodb_util.find_query_data('ths_stock_concept_detail', query)
+    # ths_stock_concept_detail = ths_stock_concept_detail[[
+    #     'concept_code',
+    #     'concept_name',
+    #     'str_now_time',
+    #     'concept_create_day']]
+    # # 去除空格
+    # ths_stock_concept_detail['concept_name'] = ths_stock_concept_detail['concept_name'].str.replace(' ', '')
+    # company_info_base.loc[:, 'ths_concept_list_info'] = ths_stock_concept_detail.to_string(index=False)
+    # for company_one in company_info_base.itertuples():
+    #     ths_concept_list_info = company_one.ths_concept_list_info
+    #     ths_concept_list_info_df = pd.read_csv(StringIO(ths_concept_list_info), delim_whitespace=True)
+    #     print(ths_concept_list_info_df)
